pub struct Texture(/* private fields */);Expand description
A high-level object to wrap textures
Implementations
Sourceimpl Texture
impl Texture
Sourcepub fn new(filename: impl AsRef<Path>) -> Self
pub fn new(filename: impl AsRef<Path>) -> Self
Create a new texture by loading an image from the filesystem
Sourcepub fn new_from_file_format(
file_data: &[u8],
format_hint: Option<ImageFormat>,
) -> Self
pub fn new_from_file_format( file_data: &[u8], format_hint: Option<ImageFormat>, ) -> Self
Creates a new texture by loading an image from encoded image data of an optionally specified format.
Sourcepub fn new_fill(width: u32, height: u32, colour: impl Into<Vec4>) -> Self
pub fn new_fill(width: u32, height: u32, colour: impl Into<Vec4>) -> Self
Create a new texture by filling it up in a single colour
Sourcepub fn new_from_image(img: DynamicImage) -> Self
pub fn new_from_image(img: DynamicImage) -> Self
Create a new texture out of an image from the image crate
Sourcepub fn new_from_data(width: u32, height: u32, data: &[u8]) -> Self
pub fn new_from_data(width: u32, height: u32, data: &[u8]) -> Self
Create a new texture out of a size and raw data
Sourcepub fn upload_region(
&self,
data: &[u8],
x: u32,
y: u32,
width: u32,
height: u32,
)
pub fn upload_region( &self, data: &[u8], x: u32, y: u32, width: u32, height: u32, )
Upload data to a specific region of the texture
Sourcepub fn upload_image_region(&self, image: RgbaImage, x: u32, y: u32)
pub fn upload_image_region(&self, image: RgbaImage, x: u32, y: u32)
Upload an image to a specific region of the image